@@ -1,8 +1,10 @@
 from dataclasses import dataclass
+from enum import IntEnum
 from typing import Dict, List, Optional
 
 import grpc
 from dependency_injector.wiring import Provide
+from pydantic import BaseModel
 
 from frogml._proto.qwak.build.v1.build_api_pb2 import (
     GetBuildRequest,
@@ -54,6 +56,8 @@ from frogml._proto.qwak.builds.builds_orchestrator_service_pb2 import (
     GetBuildVersioningDownloadURLResponse,
     GetBuildVersioningUploadURLRequest,
     GetBuildVersioningUploadURLResponse,
+    GetBuildVersioningUploadUrlsResponse,
+    GetBuildVersioningUploadUrlsRequest,
 )
 from frogml._proto.qwak.builds.builds_orchestrator_service_pb2_grpc import (
     BuildsOrchestratorServiceStub,
@@ -77,6 +81,31 @@ class HuggingModelDataClass(FrameworkModelDataClass):
     repository: Optional[str] = None
 
 
+class BuildVersioningTagsTypeEnum(IntEnum):
+    INVALID_TAG_TYPE = BuildVersioningTagsType.INVALID_TAG_TYPE
+    DATA_TAG_TYPE = BuildVersioningTagsType.DATA_TAG_TYPE
+    FILE_TAG_TYPE = BuildVersioningTagsType.FILE_TAG_TYPE
+    CODE_TAG_TYPE = BuildVersioningTagsType.CODE_TAG_TYPE
+
+    @classmethod
+    def from_proto(
+        cls, proto_value: BuildVersioningTagsType.ValueType
+    ) -> "BuildVersioningTagsTypeEnum":
+        """Convert protobuf enum value to Python enum"""
+        return cls(proto_value)
+
+    def to_proto(self) -> BuildVersioningTagsType.ValueType:
+        """Convert Python enum to protobuf enum value"""
+        return BuildVersioningTagsType.ValueType(self.value)
+
+
+class UrlInfo(BaseModel):
+    build_id: str
+    model_id: str
+    tag: str
+    tag_type: BuildVersioningTagsTypeEnum = BuildVersioningTagsTypeEnum.INVALID_TAG_TYPE
+
+
 @dataclass
 class HuggingFaceModel(FrameworkModelDataClass):
     model_name: str
@@ -220,6 +249,24 @@ class BuildOrchestratorClient:
                 f"Failed to check if build {build_id} is exists, error is {e.details()}"
             )
 
+    @grpc_try_catch_wrapper("Failed to get build versioning upload urls {url_infos}")
+    def get_build_versioning_upload_urls(
+        self, url_infos: list[UrlInfo]
+    ) -> GetBuildVersioningUploadUrlsResponse:
+        params: list[BuildVersioningUrlParams] = [
+            BuildVersioningUrlParams(
+                build_id=url_info.build_id,
+                model_id=url_info.model_id,
+                tag=url_info.tag,
+                tag_type=url_info.tag_type.to_proto(),
+            )
+            for url_info in url_infos
+        ]
+
+        return self._builds_orchestrator_stub.GetBuildVersioningUploadUrls(
+            GetBuildVersioningUploadUrlsRequest(params=params)
+        )
+
     @grpc_try_catch_wrapper("Failed to get build versioning upload url")
     def get_build_versioning_upload_url(
         self,
