@@ -3,12 +3,11 @@ import os
 from dataclasses import dataclass
 from typing import Optional
 
-from frogml.storage.authentication.utils import get_credentials
-from frogml.storage.authentication.login import frogml_login
-from frogml.storage.constants import CONFIG_FILE_PATH
-
 from frogml.core.exceptions import FrogmlLoginException
 from frogml.core.inner.tool.auth import FrogMLAuthClient
+from frogml.storage.authentication.login import frogml_login
+from frogml.storage.authentication.utils import get_credentials
+from frogml.storage.constants import CONFIG_FILE_PATH
 
 
 @dataclass
@@ -67,7 +66,7 @@ class UserAccountConfiguration:
             raise FrogmlLoginException("Failed to authenticate with JFrog")
 
         # Validate token
-        token: Optional[str] = self._auth_client.get_token()
+        token: str = self._auth_client.get_token()
         self._auth_client.validate_token(token)
 
     @staticmethod
