@@ -32,6 +32,13 @@ class FrogmlContainer(containers.DeclarativeContainer):
         enable_auth=False,
     )
 
+    non_jf_tenant_core_grpc_channel = providers.Singleton(
+        create_grpc_channel,
+        url=config.grpc.core.address,
+        enable_ssl=config.grpc.authentication.enable_ssl,
+        should_pass_jf_tenant_id=False,
+    )
+
     internal_grpc_channel_for_builds_orchestrator_factory = providers.Singleton(
         create_grpc_channel_or_none,
         url=config.grpc.builds.internal_address,
