@@ -5,14 +5,14 @@ from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING, Dict, List, Optional, Union, Iterable
 
 import requests
+from requests import Response
+from requests.auth import AuthBase
+
 from frogml._proto.qwak.build.v1.build_pb2 import DESCRIPTOR
 from frogml._proto.qwak.models.models_pb2 import (
     ListModelsMetadataResponse,
     ModelMetadata as ModelMetadataProto,
 )
-from requests import Response
-from requests.auth import AuthBase
-
 from frogml.core.clients.analytics.client import AnalyticsEngineClient
 from frogml.core.clients.automation_management.client import AutomationsManagementClient
 from frogml.core.clients.batch_job_management.client import BatchJobManagerClient
@@ -32,7 +32,6 @@ from frogml.core.clients.instance_template.client import (
 from frogml.core.clients.jfrog_gateway.client import JfrogGatewayClient
 from frogml.core.clients.model_management.client import ModelsManagementClient
 from frogml.core.clients.model_version_manager import ModelVersionManagerClient
-from frogml.core.clients.project.client import ProjectsManagementClient
 from frogml.core.exceptions import FrogmlException
 from frogml.core.inner.build_config.build_config_v1 import BuildConfigV1
 from frogml.core.inner.tool.auth import FrogMLAuthClient
@@ -50,7 +49,6 @@ from frogml.sdk.frogml_client.deployments.deployment import (
 from frogml.sdk.frogml_client.file_versioning.file_tag import FileTag
 from frogml.sdk.frogml_client.models.model import Model
 from frogml.sdk.frogml_client.models.model_metadata import ModelMetadata
-from frogml.sdk.frogml_client.projects.project import Project
 from frogml.sdk.model.base import BaseModel
 
 if TYPE_CHECKING:
@@ -67,10 +65,6 @@ class FrogMLClient:
     DeploymentClient, and more.
     """
 
-    @lru_cache(maxsize=1)
-    def _get_project_management(self) -> ProjectsManagementClient:
-        return ProjectsManagementClient()
-
     @lru_cache(maxsize=1)
     def _get_model_management(self) -> ModelsManagementClient:
         return ModelsManagementClient()
@@ -380,68 +374,6 @@ class FrogMLClient:
         """
         self._get_build_orchestrator().register_tags(build_id=build_id, tags=tags)
 
-    def create_project(
-        self,
-        project_name: str,
-        project_description: str,
-        jfrog_project_key: Optional[str] = None,
-    ) -> str:
-        """
-        Create project
-
-        Args:
-            project_name (str): The requested name
-            project_description (str): The requested description
-            jfrog_project_key (Optional[str]): The JFrog project key
-
-        Returns:
-             str: The project ID of the newly created project
-
-        """
-        project = self._get_project_management().create_project(
-            project_name=project_name,
-            project_description=project_description,
-            jfrog_project_key=jfrog_project_key,
-        )
-
-        return project.project.project_id
-
-    def get_project(self, project_id: str) -> Optional[Project]:
-        """
-        Get model by its project ID
-
-        Args:
-            project_id (str): The model ID
-
-        Returns:
-             Optional[Project]: Project by ID.
-
-        """
-        return Project.from_proto(
-            self._get_project_management().get_project(project_id).project.spec
-        )
-
-    def list_projects(self) -> List[Project]:
-        """
-        List projects
-
-        Returns:
-             List[Project]: List of projects
-
-        """
-        projects_proto = self._get_project_management().list_projects().projects
-
-        return [Project.from_proto(project) for project in projects_proto]
-
-    def delete_project(self, project_id: str) -> None:
-        """
-        Delete project by its project ID
-
-        Args:
-            project_id (str): The project ID
-        """
-        return self._get_project_management().delete_project(project_id=project_id)
-
     def create_model(
         self,
         project_id: str,
