@@ -5,10 +5,8 @@ import frogml.sdk.model_version.huggingface
 import frogml.sdk.model_version.onnx
 import frogml.sdk.model_version.pytorch
 import frogml.sdk.model_version.scikit_learn
-from frogml.sdk.model.base import BaseModel as FrogMlModel
 
 __all__ = [
-    "FrogMlModel",
     "catboost",
     "huggingface",
     "files",
