@@ -87,6 +87,11 @@ class ModelLogConfig(BaseModel):
         description="The path to the model file, this should be set only when `model_framework` is `ModelFramework.FILES`.",
         exclude=True,
     )
+    register_in_jml: bool = Field(
+        default=True,
+        description="Whether or not to register the model to JML.",
+        exclude=True,
+    )
 
     @field_validator("model_name")
     @classmethod
