@@ -1,4 +1,5 @@
-from typing import List, Optional, Union
+import getpass
+from typing import List, Optional
 
 from frogml.storage.authentication.login._login_command import run as run_login
 from frogml.storage.authentication.models import LoginArguments
@@ -67,7 +68,7 @@ def __get_failed_reason(
     return details
 
 
-def __run_interactive_mode() -> Union[LoginArguments, None]:
+def __run_interactive_mode() -> Optional[LoginArguments]:
     jfrog_cli_config = read_jfrog_cli_config()
 
     if jfrog_cli_config is not None:
@@ -84,7 +85,9 @@ def __run_interactive_mode() -> Union[LoginArguments, None]:
                 or int(login_method_id) > 2
                 or int(login_method_id) <= 0
             ):
-                login_method_id = input("Bad Input. Choose your preferred login option")
+                login_method_id = input(
+                    "Bad Input. Choose your preferred login option:\n"
+                )
 
             login_method_id = int(login_method_id)
             if login_method_id == 1:
@@ -97,55 +100,52 @@ def __run_interactive_mode() -> Union[LoginArguments, None]:
     return None
 
 
-def __prompt_manual_details() -> Union[LoginArguments, None]:
+def __prompt_manual_details() -> Optional[LoginArguments]:
     login_args = LoginArguments()
-    login_args.server_id = input("Enter server ID: ")
-    login_args.artifactory_url = input("Enter artifactory base url")
+    login_args.server_id = input("Enter server ID (optional): ")
+    login_args.artifactory_url = input("Enter artifactory base url: ")
 
     if login_args.artifactory_url is not None:
         login_args.artifactory_url = join_url(login_args.artifactory_url, "artifactory")
 
-    auth_options = ["Username and Password", "Access Token", "Anonymous Access"]
+    auth_options = ["Username and Password", "Access Token"]
     authentication_types = ""
     for index, item in enumerate(auth_options):
-        authentication_types += f"{index}: {item} \n"
+        authentication_types += f"{index+1}: {item} \n"
     selected_auth_type = input(
         f"Choose your preferred authentication option:\n{authentication_types}"
     )
     while (
         not selected_auth_type.isdigit()
-        or int(selected_auth_type) >= len(auth_options)
-        or int(selected_auth_type) < 0
+        or int(selected_auth_type) >= len(auth_options) + 1
+        or int(selected_auth_type) <= 0
     ):
-        selected_auth_type = input("Bad Input. Choose your preferred authentication")
+        selected_auth_type = input("Bad Input. Choose your preferred authentication:\n")
     selected_auth_type = int(selected_auth_type)
-    if selected_auth_type == 0:
+    if selected_auth_type == 1:
         return __prompt_username_password(login_args)
-    elif selected_auth_type == 1:
-        return __prompt_access_token(login_args)
     elif selected_auth_type == 2:
-        login_args.isAnonymous = True
-        return login_args
+        return __prompt_access_token(login_args)
     return None
 
 
 def __prompt_username_password(login_args: LoginArguments) -> LoginArguments:
-    username = input("Enter JFrog user name")
-    password = input("Enter JFrog password")
+    username = input("Enter JFrog user name: ")
+    password = getpass.getpass(prompt="Enter JFrog password: ")
     login_args.username = username
     login_args.password = password
     return login_args
 
 
 def __prompt_access_token(login_args: LoginArguments) -> LoginArguments:
-    token = input("Enter JFrog access token")
+    token = getpass.getpass("Enter JFrog access token: ")
     login_args.access_token = token
     return login_args
 
 
 def __prompt_jfrog_cli_configuration_list(
     jfrog_cli_config: dict, jfrog_cli_servers: List[str]
-) -> Union[LoginArguments, None]:
+) -> Optional[LoginArguments]:
     list_server_options = ""
     for index, item in enumerate(jfrog_cli_servers):
         list_server_options += f"{index}: {item}\n"
@@ -195,7 +195,7 @@ def __login_by_frogml_configuration_file_flow() -> bool:
 
 
 def __interactive_flow() -> bool:
-    login_args = __run_interactive_mode()
+    login_args: Optional[LoginArguments] = __run_interactive_mode()
     if login_args is not None:
         return __execute_login(login_args)
     return False
