@@ -1,9 +1,10 @@
 import http
 import json
 import os
-from typing import Optional, Tuple, Union, List
+from typing import Optional, Tuple, Union, List, cast, Iterable
 
 import requests
+from cachetools import cached, LRUCache
 from requests import Response, HTTPError
 from requests.auth import AuthBase, HTTPBasicAuth
 
@@ -216,10 +217,12 @@ def save_auth_config(login_args: LoginArguments) -> None:
         json.dump(file_content, file, indent=2)
 
 
-def get_credentials(auth_config: Optional[AuthConfig] = None) -> Tuple[str, AuthBase]:
+@cached(cache=LRUCache(maxsize=1))
+def get_credentials(
+    auth_config: Optional[AuthConfig] = None,
+) -> Tuple[str, Union[EmptyAuth, BearerAuth]]:
     if not __should_use_file_auth(auth_config):
-        __validate_credentials(auth_config)
-        return __auth_config_to_auth_tuple(auth_config)
+        return __auth_config_to_auth_tuple(cast(AuthConfig, auth_config))
     logger.debug(
         "Login configuration not supplied, attempting to find environment variables"
     )
@@ -233,6 +236,7 @@ def get_credentials(auth_config: Optional[AuthConfig] = None) -> Tuple[str, Auth
 
     if os.path.exists(CONFIG_FILE_PATH):
         return __read_credentials_from_file(CONFIG_FILE_PATH)
+
     raise ValueError(
         f"Configuration were not provided and configuration file not found in {CONFIG_FILE_PATH},"
         f" either pass configuration in the constructor, add env variables or create the configuration file by "
@@ -262,15 +266,16 @@ def __should_use_file_auth(credentials: Optional[AuthConfig] = None) -> bool:
     )
 
 
-def __validate_credentials(credentials: Optional[AuthConfig]) -> None:
-    if credentials is None:
-        raise ValueError("Credentials must be provided.")
-    if credentials.artifactory_url is None:
+def __validate_credentials(auth_config: AuthConfig) -> None:
+    if auth_config.artifactory_url is None:
         raise ValueError("Credentials must contain artifactory url.")
+
     return None
 
 
-def __read_credentials_from_file(file_path: str) -> Tuple[str, AuthBase]:
+def __read_credentials_from_file(
+    file_path: str,
+) -> Tuple[str, Union[BearerAuth, EmptyAuth]]:
     try:
         with open(file_path, "r") as file:
             config_content: dict = json.load(file)
@@ -286,35 +291,30 @@ def __read_credentials_from_file(file_path: str) -> Tuple[str, AuthBase]:
 
 
 def __auth_config_to_auth_tuple(
-    auth_config: Optional[AuthConfig],
-) -> Tuple[str, AuthBase]:
+    auth_config: AuthConfig,
+) -> Tuple[str, Union[BearerAuth, EmptyAuth]]:
+    __validate_credentials(auth_config)
 
-    if auth_config is None:
-        raise ValueError("No authentication configuration provided")
+    artifactory_url: str = auth_config.artifactory_url
 
-    auth: AuthBase = EmptyAuth()
     if auth_config.access_token is not None:
-        auth = BearerAuth(auth_config.access_token)
+        return artifactory_url, BearerAuth(auth_config.access_token)
 
-    if auth_config.artifactory_url is None:
-        raise ValueError("No artifactory URL provided")
-
-    return auth_config.artifactory_url, auth
+    return artifactory_url, EmptyAuth()
 
 
-def get_list_of_servers_from_config(jfrog_cli_config: dict) -> List[str]:
-    if jfrog_cli_config is not None:
-        servers = jfrog_cli_config.get("servers")
-        if servers is not None:
-            return list(map(__map_server_ids, servers))
+def get_list_of_servers_from_config(jfrog_cli_config: Optional[dict]) -> List[str]:
+    if not jfrog_cli_config or not jfrog_cli_config.get("servers"):
+        return []
 
-    return []
+    servers: Iterable[dict] = jfrog_cli_config["servers"]
+    return list(map(__map_server_ids, servers))
 
 
 def __map_server_ids(server: dict) -> str:
-    server_id = ""
-    if server is not None:
-        server_id = str(server.get("serverId"))
-        if server.get("isDefault") is not None and bool(server.get("isDefault")):
-            server_id = server_id + " (Default)"
+    server_id = str(server.get("serverId"))
+
+    if server.get("isDefault"):
+        server_id += " (Default)"
+
     return server_id
