@@ -31,7 +31,9 @@ from frogml._proto.qwak.automation.v1.automation_management_service_pb2_grpc imp
 from frogml._proto.qwak.batch_job.v1.batch_job_service_pb2_grpc import (
     add_BatchJobManagementServiceServicer_to_server,
 )
-from frogml._proto.qwak.build.v1.build_api_pb2_grpc import add_BuildAPIServicer_to_server
+from frogml._proto.qwak.build.v1.build_api_pb2_grpc import (
+    add_BuildAPIServicer_to_server,
+)
 from frogml._proto.qwak.build_settings.build_settings_api_pb2_grpc import (
     add_BuildSettingsApiServicer_to_server,
 )
@@ -50,8 +52,9 @@ from frogml._proto.qwak.deployment.alert_service_pb2_grpc import (
 from frogml._proto.qwak.deployment.deployment_service_pb2_grpc import (
     add_DeploymentManagementServiceServicer_to_server,
 )
-from frogml._proto.qwak.ecosystem.jfrog.v0.jfrog_tenant_info_service_pb2_grpc import \
-    add_JFrogTenantInfoServiceServicer_to_server
+from frogml._proto.qwak.ecosystem.jfrog.v0.jfrog_tenant_info_service_pb2_grpc import (
+    add_JFrogTenantInfoServiceServicer_to_server,
+)
 from frogml._proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2_grpc import (
     add_QwakEcosystemRuntimeServicer_to_server as add_FrogmlEcosystemRuntimeServicer_to_server,
 )
@@ -91,7 +94,9 @@ from frogml._proto.qwak.kube_deployment_captain.kube_deployment_captain_service_
 from frogml._proto.qwak.logging.log_reader_service_pb2_grpc import (
     add_LogReaderServiceServicer_to_server,
 )
-from frogml._proto.qwak.model_group.model_group_pb2_grpc import add_ModelGroupManagementServiceServicer_to_server
+from frogml._proto.qwak.model_group.model_group_pb2_grpc import (
+    add_ModelGroupManagementServiceServicer_to_server,
+)
 from frogml._proto.qwak.models.models_pb2_grpc import (
     add_ModelsManagementServiceServicer_to_server,
 )
@@ -101,7 +106,9 @@ from frogml._proto.qwak.monitoring.v0.alerting_channel_management_service_pb2_gr
 from frogml._proto.qwak.offline.serving.v1.offline_serving_async_service_pb2_grpc import (
     add_FeatureStoreOfflineServingAsyncServiceServicer_to_server,
 )
-from frogml._proto.qwak.projects.projects_pb2_grpc import add_ProjectsManagementServiceServicer_to_server
+from frogml._proto.qwak.projects.projects_pb2_grpc import (
+    add_ProjectsManagementServiceServicer_to_server,
+)
 from frogml._proto.qwak.secret_service.secret_service_pb2_grpc import (
     add_SecretServiceServicer_to_server,
 )
@@ -169,7 +176,9 @@ from frogml_services_mock.mocks.integration_management_service import (
 from frogml_services_mock.mocks.internal_build_orchestrator_service import (
     InternalBuildOrchestratorServiceMock,
 )
-from frogml_services_mock.mocks.jfrog_tenant_info_service_mock import JFrogTenantInfoServiceMock
+from frogml_services_mock.mocks.jfrog_tenant_info_service_mock import (
+    JFrogTenantInfoServiceMock,
+)
 from frogml_services_mock.mocks.job_registry_service_api import (
     JobRegistryServiceApiMock,
 )
@@ -180,7 +189,9 @@ from frogml_services_mock.mocks.location_discovery_service_api import (
     LocationDiscoveryServiceApiMock,
 )
 from frogml_services_mock.mocks.logging_service import LoggingServiceApiMock
-from frogml_services_mock.mocks.model_group_management_service import ModelGroupManagementServiceMock
+from frogml_services_mock.mocks.model_group_management_service import (
+    ModelGroupManagementServiceMock,
+)
 from frogml_services_mock.mocks.model_management_service import (
     ModelsManagementServiceMock,
 )
@@ -219,39 +230,39 @@ def frogml_container():
             },
         },
     )
-    from frogml.core.clients import kube_deployment_captain
-    from frogml.core.clients import model_version_manager
-    from frogml.core.clients import analytics
-    from frogml.core.clients import autoscaling
-    from frogml.core.clients import build_orchestrator
-    from frogml.core.clients import batch_job_management
-    from frogml.core.clients import instance_template
-    from frogml.core.clients import feature_store
-    from frogml.core.clients import deployment
-    from frogml.core.clients import user_application_instance
-    from frogml.core.clients import jfrog_gateway
-    from frogml.core.clients import location_discovery
-    from frogml.core.clients import alert_management
-    from frogml.core.clients import model_management
-    from frogml.core.clients import model_group_management
-    from frogml.core.clients import audience
-    from frogml.core.clients import data_versioning
-    from frogml.core.clients import logging_client
-    from frogml.core.clients import automation_management
-    from frogml.core.clients import file_versioning
-    from frogml.core.clients import alerts_registry
-    from frogml.core.clients import secret_service
-    from frogml.core.clients.administration import eco_system
-    from frogml.core.clients.administration import self_service
-    from frogml.core.clients.administration import authentication
+    from frogml.core.clients import (
+        alert_management,
+        alerts_registry,
+        analytics,
+        audience,
+        automation_management,
+        autoscaling,
+        batch_job_management,
+        build_orchestrator,
+        data_versioning,
+        deployment,
+        feature_store,
+        file_versioning,
+        instance_template,
+        jfrog_gateway,
+        kube_deployment_captain,
+        location_discovery,
+        logging_client,
+        model_group_management,
+        model_management,
+        model_version_manager,
+        secret_service,
+        user_application_instance,
+    )
+    from frogml.core.clients.administration import eco_system, self_service, authentication
     from frogml.core.clients.integration_management import integration_manager_client
     from frogml.core.clients.system_secret import system_secret_client
 
     container.wire(
         packages=[
-            authentication,
             alert_management,
             audience,
+            authentication,
             automation_management,
             autoscaling,
             analytics,
